pub fn generate_cache_key(path: &str, config: &AiOutputConfig) -> StringExpand description
Generate a cache key for a given path and configuration This enables AI clients to short-circuit repeated calls
pub fn generate_cache_key(path: &str, config: &AiOutputConfig) -> StringGenerate a cache key for a given path and configuration This enables AI clients to short-circuit repeated calls