Structs
Functions
- check_
client_ compression_ support - Check if a client response indicates compression support
- compress_
string - Compress a string using zlib
- configure_
compression - Configure compression settings
- create_
compression_ test - Test if client supports compression by including a small compressed hint
- get_
compression_ stats - Get compression statistics
- set_
compression_ support - Set global compression support status
- should_
compress_ response - Check if we should compress a response based on its size
- smart_
compress_ mcp_ response - Smart compress any MCP response content