Module content_detector

Module content_detector 

Content detection engine - “Understanding what’s in your directories” - Omni Analyzes directory contents to determine the type of project/collection

Structs

ContentDetector
Analyzes a directory and detects its content type

Enums

DirectoryType
Types of content that can be detected in a directory
Framework
Language