Module feature_flags

Module feature_flags 

Structs

FeatureFlags
Feature flags for controlling Smart Tree capabilities Organizations can disable features via config file or environment variables
McpToolFlags

Enums

ComplianceMode

Functions

features
Get the global feature flags
is_enabled
Check if a feature is enabled (convenience function)