pub struct SmartTreeMem8 { /* private fields */ }Expand description
MEM8 integration for Smart Tree
Implementations
Sourceimpl SmartTreeMem8
Extension for MEM8 to create developer-specific wave patterns
impl SmartTreeMem8
Extension for MEM8 to create developer-specific wave patterns
Sourcepub fn import_developer_personas(
&mut self,
repo_path: impl AsRef<Path>,
) -> Result<()>
pub fn import_developer_personas( &mut self, repo_path: impl AsRef<Path>, ) -> Result<()>
Import developer personas as unique wave signatures
Sourcepub fn query_developer_memories(
&self,
_developer_name: &str,
) -> Vec<(MemoryWave, String)>
pub fn query_developer_memories( &self, _developer_name: &str, ) -> Vec<(MemoryWave, String)>
Query memories specific to a developer
Sourceimpl SmartTreeMem8
Extension trait to integrate Git temporal data with MEM8
impl SmartTreeMem8
Extension trait to integrate Git temporal data with MEM8
Sourceimpl SmartTreeMem8
impl SmartTreeMem8
Sourcepub fn store_directory_memory(
&mut self,
path: &Path,
metadata: DirectoryMetadata,
) -> Result<()>
pub fn store_directory_memory( &mut self, path: &Path, metadata: DirectoryMetadata, ) -> Result<()>
Store a directory entry as a wave memory
Sourcepub fn simple_hash(&self, s: &str) -> u64
pub fn simple_hash(&self, s: &str) -> u64
Simple hash function for path distribution
Sourcepub fn query_path_memories(&self, pattern: &str) -> Vec<PathMemory>
pub fn query_path_memories(&self, pattern: &str) -> Vec<PathMemory>
Query memories about a specific path pattern
Sourcepub fn register_directory_patterns(&mut self)
pub fn register_directory_patterns(&mut self)
Register reactive patterns for directory events
Sourcepub fn process_directory_event(
&self,
event: DirectoryEvent,
) -> Option<ReactiveResponse>
pub fn process_directory_event( &self, event: DirectoryEvent, ) -> Option<ReactiveResponse>
Process directory scan event through reactive system
Sourcepub fn update_consciousness(&self)
pub fn update_consciousness(&self)
Update consciousness state
Sourcepub fn export_memories<W: Write>(&self, writer: W) -> Result<()>
pub fn export_memories<W: Write>(&self, writer: W) -> Result<()>
Export memories to .m8 format
Sourcepub fn active_memory_count(&self) -> usize
pub fn active_memory_count(&self) -> usize
Get count of active memories
Sourcepub fn store_wave_at_coordinates(
&mut self,
x: u8,
y: u8,
z: u16,
wave: MemoryWave,
) -> Result<()>
pub fn store_wave_at_coordinates( &mut self, x: u8, y: u8, z: u16, wave: MemoryWave, ) -> Result<()>
Store wave at specific coordinates (public helper method)
Sourcepub fn string_to_coordinates(&self, s: &str) -> (u8, u8)
pub fn string_to_coordinates(&self, s: &str) -> (u8, u8)
Helper to convert string to coordinates