pub enum FilesystemType {
Show 19 variants
Ext4,
Ext3,
Ext2,
Xfs,
Btrfs,
Zfs,
Ntfs,
Fat32,
ExFat,
Apfs,
Hfs,
Nfs,
Smb,
Tmpfs,
Procfs,
Sysfs,
Devfs,
Mem8,
Unknown,
}Expand description
FilesystemType: Identifying the underlying filesystem
This enum represents different filesystem types with single-character codes for compact display. The mapping is designed to be memorable and intuitive.
Variants
Ext4
Ext3
Ext2
Xfs
Btrfs
Zfs
Ntfs
Fat32
ExFat
Apfs
Hfs
Nfs
Smb
Tmpfs
Procfs
Sysfs
Devfs
Mem8
Unknown
Implementations
Sourceimpl FilesystemType
impl FilesystemType
Sourcepub fn is_virtual(&self) -> bool
pub fn is_virtual(&self) -> bool
Check if this is a virtual filesystem that should be skipped
Sourcepub fn should_show_by_default(&self) -> bool
pub fn should_show_by_default(&self) -> bool
Check if this filesystem type should be shown by default (only “interesting” filesystems based on platform)