Module std_client

Module std_client 

STD Client - Talk to the Smart Tree Daemon via Unix socket

This module provides a client for the ST binary protocol daemon. Falls back gracefully to local operation if daemon isn’t running.

“The thin client to the fat brain!” - Cheet

Structs

StdClient
Client for communicating with the STD daemon

Functions

ensure_daemon
Ensure daemon is running, with user feedback
is_daemon_running
Check if the STD daemon is running
socket_path
Get the default socket path
start_daemon
Start the STD daemon in the background