Daemon CLI Handlers - HTTP endpoints for thin-client CLI operations
This module provides the daemon endpoints that the st thin client
calls to perform scanning and formatting operations. All the heavy
lifting happens here in the daemon.
“The meat stays in the daemon!” - Hue
Structs
- CliError
Response - Error response
- CliScan
Request - CLI scan request - all options from the CLI
- CliScan
Response - CLI scan response
- Scan
Stats - Scan statistics
Functions
- cli_
scan_ handler - Handle CLI scan request
- cli_
stream_ handler - Handle streaming CLI scan request (SSE) - simplified version For now, this just returns the full response as JSON TODO: Implement proper SSE streaming