Structs
- Feature
Flags - Feature flags for controlling Smart Tree capabilities Organizations can disable features via config file or environment variables
- McpTool
Flags
Enums
Functions
- features
- Get the global feature flags
- is_
enabled - Check if a feature is enabled (convenience function)